import React from 'react';
import HostStore from "../../../stores/HostStore";
import DesignStore from "./../../../stores/DesignStore";
import * as SIP from 'sip.js'
import ContactDetail from "./ContactDetail";
import LanguageStore from "./../../../stores/LanguageStore";
import axios from 'axios';
import { properties } from '../../../properties.js';
import MSButton from "./../../UI/MSButton";

class ContactSearch extends React.Component {

  constructor(props){
    super(props)
    this.state ={
      callstatus :"nocall",
      hosts: HostStore.loadHosts(),
      designs : DesignStore.getDesign(),
      selection: null
    }
    this.sip = null;
    this.updateHosts = this.updateHosts.bind(this);
    this.listHosts = this.listHosts.bind(this);
    this.selectHost = this.selectHost.bind(this);
    this.call = this.call.bind(this);
    this.endcall = this.endcall.bind(this);
  }

  selectHost(e, host){
    this.setState({
      selection : host
    });
  }

  componentDidMount (){
    DesignStore.on("design_loaded", this.update);
    HostStore.on("hosts_loaded", this.updateHosts);
  }

  update(){
    this.setState({
      designs : DesignStore.getDesign()
    })
  }

  updateHosts(){
    this.setState({
      hosts : HostStore.getHosts()
    })
  }

  listHosts(){
    return(
      <div className="main_view" id="contact_list">
          { this.state.hosts.map(function(host, index){
            let styles =[];
            if(this.state.designs){
              if( (index%2) !== 0){
                styles = {
                  backgroundColor: this.state.designs["main_color"],
                  color: "#fff"
                };
              }
            }

            return(
              <div onClick={(e) => this.selectHost(e, host)} className="singleHost" style={styles} key={ index } >
                <span  className="host_infos" >{host.pe_name}, {host.pe_vorname}</span>
              </div>
          );
          }.bind(this)) }

      </div>
    )
  }

  call(){

    axios.get("/customportals/startcall.php?SID=" +
      properties.key + "&number=" + encodeURI(this.state.selection.pe_tel_1))
      .then(res => {
        this.setState({
          callstatus:"calling"
        });
      })

  }

  endcall(){

    axios.get("/customportals/endcall.php?SID=" +
      properties.key + "&number=" + encodeURI(this.state.selection.pe_tel_1))
      .then(res => {
        this.setState({
          callstatus:"nocall"
        });
      })

  }

  showDetails(){
    if(this.state.selection){
      return(

        <div id="details">
          <div id="detail_lastname" className="info">{LanguageStore.translate("lastname")}: {this.state.selection.pe_name}</div>
          <div id="detail_firstname" className="info">{LanguageStore.translate("firstname")}: {this.state.selection.pe_vorname}</div>
          <div id="detail_division" className="info">{LanguageStore.translate("division")}: {this.state.selection.pe_department}</div>
          <div id="detail_room" className="info">{LanguageStore.translate("room")}: {this.state.selection.pe_room_nr}</div>
          <div id="detail_floor" className="info">{LanguageStore.translate("floor")}: {this.state.selection.pe_floor}</div>
          <div id="detail_building"  className="info">{LanguageStore.translate("building")}: {this.state.selection.pe_building} / {this.state.selection.pe_building_part}</div>

          {this.state.selection.pe_tel_1 && this.state.callstatus === "nocall"  &&
            <div className="info" id="info_call_control">
              <button className="btn btn-default" id="call_btn" onClick={this.call} >{LanguageStore.translate("call")}</button>
            </div>
          }

          {this.state.selection.pe_tel_1 && this.state.callstatus === "calling"  &&
            <div className="info">
              <button className="btn btn-default" id="call_end_btn" onClick={this.endcall} >{LanguageStore.translate("call_end")}</button>
            </div>
          }
        </div>

      );
    }else{
      return(<div />);
    }
  }

  render() {

    let content = <div>Loading ... </div>;
    let details ="";

    if(this.state.hosts !== null && this.state.hosts !== undefined ){
      content = this.listHosts();
      details = this.showDetails();
    }

    return (
      <div id="ContactSearch" className="main_view">
        <h1>{LanguageStore.translate("contacts")}</h1>
        {content}
        {details}
      </div>
    );
  }
}

export default ContactSearch;
